==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1HTTPIngressPathFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta1HTTPIngressPathFluentImpl<A extends V1beta1HTTPIngressPathFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1HTTPIngressPathFluent<A>{

    private V1beta1IngressBackendBuilder backend;
    private String path;

    public V1beta1HTTPIngressPathFluentImpl(){
    }
    public V1beta1HTTPIngressPathFluentImpl(V1beta1HTTPIngressPath instance){
            this.withBackend(instance.getBackend());

            this.withPath(instance.getPath());

    }

    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1IngressBackend getBackend(){
            return this.backend!=null?this.backend.build():null;
    }

    public V1beta1IngressBackend buildBackend(){
            return this.backend!=null?this.backend.build():null;
    }

    public A withBackend(V1beta1IngressBackend backend){
            _visitables.remove(this.backend);
            if (backend!=null){ this.backend= new V1beta1IngressBackendBuilder(backend); _visitables.add(this.backend);} return (A) this;
    }

    public Boolean hasBackend(){
            return this.backend != null;
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackend(){
            return new BackendNestedImpl();
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(V1beta1IngressBackend item){
            return new BackendNestedImpl(item);
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> editBackend(){
            return withNewBackendLike(getBackend());
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackend(){
            return withNewBackendLike(getBackend() != null ? getBackend(): new V1beta1IngressBackendBuilder().build());
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(V1beta1IngressBackend item){
            return withNewBackendLike(getBackend() != null ? getBackend(): item);
    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1HTTPIngressPathFluentImpl that = (V1beta1HTTPIngressPathFluentImpl) o;
            if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            return true;
    }


    public class BackendNestedImpl<N> extends V1beta1IngressBackendFluentImpl<V1beta1HTTPIngressPathFluent.BackendNested<N>> implements V1beta1HTTPIngressPathFluent.BackendNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1IngressBackendBuilder builder;
    
            BackendNestedImpl(V1beta1IngressBackend item){
                    this.builder = new V1beta1IngressBackendBuilder(this, item);
            }
            BackendNestedImpl(){
                    this.builder = new V1beta1IngressBackendBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1HTTPIngressPathFluentImpl.this.withBackend(builder.build());
    }
    public N endBackend(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1HTTPIngressPathFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta1HTTPIngressPathFluentImpl<A extends V1beta1HTTPIngressPathFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1HTTPIngressPathFluent<A>{

    private V1beta1IngressBackendBuilder backend;
    private String path;

    public V1beta1HTTPIngressPathFluentImpl(){
    }
    public V1beta1HTTPIngressPathFluentImpl(V1beta1HTTPIngressPath instance){
            this.withBackend(instance.getBackend());

            this.withPath(instance.getPath());

    }

    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1IngressBackend getBackend(){
            return this.backend!=null?this.backend.build():null;
    }

    public V1beta1IngressBackend buildBackend(){
            return this.backend!=null?this.backend.build():null;
    }

    public A withBackend(V1beta1IngressBackend backend){
            _visitables.get("backend").remove(this.backend);
            if (backend!=null){ this.backend= new V1beta1IngressBackendBuilder(backend); _visitables.get("backend").add(this.backend);} return (A) this;
    }

    public Boolean hasBackend(){
            return this.backend != null;
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackend(){
            return new BackendNestedImpl();
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(V1beta1IngressBackend item){
            return new BackendNestedImpl(item);
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> editBackend(){
            return withNewBackendLike(getBackend());
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackend(){
            return withNewBackendLike(getBackend() != null ? getBackend(): new V1beta1IngressBackendBuilder().build());
    }

    public V1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(V1beta1IngressBackend item){
            return withNewBackendLike(getBackend() != null ? getBackend(): item);
    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public A withNewPath(String arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuilder arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1){
            return (A)withPath(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1HTTPIngressPathFluentImpl that = (V1beta1HTTPIngressPathFluentImpl) o;
            if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            return true;
    }


    public class BackendNestedImpl<N> extends V1beta1IngressBackendFluentImpl<V1beta1HTTPIngressPathFluent.BackendNested<N>> implements V1beta1HTTPIngressPathFluent.BackendNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta1IngressBackendBuilder builder;
    
            BackendNestedImpl(V1beta1IngressBackend item){
                    this.builder = new V1beta1IngressBackendBuilder(this, item);
            }
            BackendNestedImpl(){
                    this.builder = new V1beta1IngressBackendBuilder(this);
            }
    
    public N and(){
            return (N) V1beta1HTTPIngressPathFluentImpl.this.withBackend(builder.build());
    }
    public N endBackend(){
            return and();
    }

}


}
